@@ -20,34 +20,49 @@
 #ifndef KRUNNERCONFIG_H
 #define KRUNNERCONFIG_H
 
-#include <KDialog>
 
-class KPluginSelector;
+#include <KTabWidget>
+
+#include "ui_interfaceOptions.h"
+
+class KRunnerDialog;
+
 class QDialogButtonBox;
 class QTabWidget;
 
+class KPluginSelector;
+
 namespace Plasma {
     class RunnerManager;
 }
 
-class KRunnerConfigDialog : public KDialog
+class KRunnerConfigWidget : public QWidget
 {
 Q_OBJECT
     public:
-        KRunnerConfigDialog(Plasma::RunnerManager* manager, QWidget* parent = 0);
-        ~KRunnerConfigDialog();
+        KRunnerConfigWidget(Plasma::RunnerManager *manager, QWidget *parent = 0);
+        ~KRunnerConfigWidget();
 
-    public slots:
-        void accept();
+    Q_SIGNALS:
+        void finished();
 
     private slots:
-        void updateRunner(const QByteArray&);
+        void save(QAbstractButton *pushed);
+        void previewInterface();
+        void setInterface(int type);
+        void updateRunner(const QByteArray& runnerName);
+        void syncPalette();
 
     private:
         void init();
 
-        KPluginSelector* m_sel;
-        Plasma::RunnerManager* m_manager;
+        int m_interfaceType;
+        KRunnerDialog *m_preview;
+        KPluginSelector *m_sel;
+        KTabWidget *m_tabWidget;
+        QDialogButtonBox *m_buttons;
+        Plasma::RunnerManager *m_manager;
+        Ui::InterfaceOptions m_uiOptions;
 };
 
 #endif
