@@ -30,12 +30,13 @@
 
 #include <Plasma/QueryMatch>
 
+#include "resultitem.h"
+
 namespace Plasma
 {
     class RunnerManager;
 }
 
-class ResultItem;
 class SelectionBar;
 
 class ResultScene : public QGraphicsScene
@@ -43,17 +44,14 @@ class ResultScene : public QGraphicsScene
     Q_OBJECT
 
     public:
-        explicit ResultScene(Plasma::RunnerManager *runnerManager, QWidget *focusBase, QObject *parent = 0);
+        explicit ResultScene(SharedResultData *resultData, Plasma::RunnerManager *runnerManager, QWidget *focusBase, QObject *parent = 0);
         ~ResultScene();
 
-        void resize(int width, int height);
+        void setWidth(int width);
         ResultItem* defaultResultItem() const;
         void run(ResultItem* item) const;
         QSize minimumSizeHint() const;
-        void setItemsAcceptHoverEvents(bool enable);
-        bool itemsAcceptHoverEvents();
-//        Plasma::RunnerManager* manager() const;
-
+        int viewableHeight() const;
 
     public slots:
         void setQueryMatches(const QList<Plasma::QueryMatch> &matches);
@@ -63,15 +61,12 @@ class ResultScene : public QGraphicsScene
 
     signals:
         void itemActivated(ResultItem *item);
-        void itemHoverEnter(ResultItem *item);
-        void itemHoverLeave(ResultItem *item);
         void matchCountChanged(int count);
         void ensureVisibility(QGraphicsItem *item);
 
     protected:
         void keyPressEvent(QKeyEvent * keyEvent);
         void focusInEvent(QFocusEvent *focusEvent);
-        void focusOutEvent(QFocusEvent *focusEvent);
 
     private:
         void selectPreviousItem();
@@ -79,27 +74,26 @@ class ResultScene : public QGraphicsScene
 
         ResultItem* currentlyFocusedItem() const;
 
-        ResultItem* addQueryMatch(const Plasma::QueryMatch &match, bool useAnyId);
-
         bool canMoveItemFocus() const;
+        void arrangeItems(bool setFocusAndTabbing);
 
     private slots:
         void clearMatches();
         void updateItemMargins();
-        void arrangeItems(ResultItem *);
-        void initItemsHoverEvents();
+        void scheduleArrangeItems();
+        void arrangeItems();
+        void highlightItem(QGraphicsItem *item);
 
     private:
         Plasma::RunnerManager *m_runnerManager;
 
-        QSize       m_size;
         QTimer      m_clearTimer;
-        QTimer      m_hoverTimer;
+        QTimer      m_arrangeTimer;
 
-        QList<ResultItem *>  m_items;
-        QMultiMap<QString, ResultItem *>  m_itemsById;
+        QList<ResultItem *> m_items;
         SelectionBar *m_selectionBar;
 
+        int m_viewableHeight;
         int m_currentIndex;
         qreal m_itemMarginLeft;
         qreal m_itemMarginTop;
@@ -107,7 +101,8 @@ class ResultScene : public QGraphicsScene
         qreal m_itemMarginBottom;
 
         QWidget *m_focusBase;
-        bool m_itemsAcceptHoverEvents;
+
+        SharedResultData *m_resultData;
 };
 
 #endif
