@@ -120,8 +120,16 @@ void KSMShutdownFeedback::start()
             if( props != NULL )
                 XFree( props );
         }
-        if( wmsupport )
+        if( wmsupport ) {
+            // Announce that the user MAY be logging out (Intended for the compositor)
+            Atom announce = XInternAtom(dpy, "_KDE_LOGGING_OUT", False);
+            unsigned char dummy = 0;
+            XChangeProperty(dpy, QX11Info::appRootWindow(), announce, announce, 8, PropModeReplace,
+                &dummy, 1);
+
+            // Don't show our own effect
             return;
+        }
     }
     s_pSelf = new KSMShutdownFeedback();
     s_pSelf->show();
@@ -133,6 +141,16 @@ void KSMShutdownFeedback::stop()
     s_pSelf = NULL;
 }
 
+void KSMShutdownFeedback::logoutCanceled()
+{
+    if( KWindowSystem::compositingActive()) {
+        // We are no longer logging out, announce (Intended for the compositor)
+        Display* dpy = QX11Info::display();
+        Atom announce = XInternAtom(dpy, "_KDE_LOGGING_OUT", False);
+        XDeleteProperty(QX11Info::display(), QX11Info::appRootWindow(), announce);
+    }
+}
+
 ////////////
 
 KSMPushButton::KSMPushButton( const QString &text, QWidget *parent, bool smallButton )
@@ -146,19 +164,20 @@ KSMPushButton::KSMPushButton( const QString &text, QWidget *parent, bool smallBu
 
 void KSMPushButton::init()
 {
+    m_glowSvg = new Plasma::Svg(this);
+    m_glowSvg->setImagePath("dialogs/shutdowndialog");
+
     if (m_smallButton) {
         setMinimumSize(88, 22);
         setFixedHeight(22); // workaround: force correct height
     } else {
-        setMinimumSize(165, 38);
+        setMinimumSize(m_glowSvg->elementSize("button-normal"));
         setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     }
 
     connect( this, SIGNAL(pressed()), SLOT(slotPressed()) );
     connect( this, SIGNAL(released()), SLOT(slotReleased()) );
 
-    m_glowSvg = new Plasma::Svg(this);
-    m_glowSvg->setImagePath("dialogs/shutdowndialog");
     connect( m_glowSvg, SIGNAL(repaintNeeded()), this, SLOT(update()) );
 
     m_glowTimeLine = new QTimeLine( 150, this );
@@ -211,6 +230,8 @@ void KSMPushButton::paintEvent( QPaintEvent * e )
 
     p.save();
 
+    m_glowSvg->resize();
+
     if (m_glowOpacity > 0) {
         p.setOpacity(m_glowOpacity); // fade in
         m_glowSvg->paint(&p, QRect(0, 0, width(), height()), m_smallButton ? "button-small-hover" : "button-hover");
@@ -218,7 +239,6 @@ void KSMPushButton::paintEvent( QPaintEvent * e )
         m_glowSvg->paint(&p, QRect(0, 0, width(), height()), m_smallButton ? "button-small-normal" : "button-normal");
         p.setOpacity(1.0);
     } else {
-        m_glowSvg->resize();
         m_glowSvg->paint(&p, QRect(0, 0, width(), height()), m_smallButton ? "button-small-normal" : "button-normal");
     }
 
@@ -238,10 +258,11 @@ void KSMPushButton::paintEvent( QPaintEvent * e )
         p.setBrush(fntColor);
         pen.setColor(QColor(fntColor));
         p.setPen( pen );
+        int baseY = height()/2 + m_pixmap.height()/2;
         QPoint points[3] = {
-            QPoint(width() - 10 - 34, height() - 7),
-            QPoint(width() - 4 - 34, height() - 7),
-            QPoint(width() - 7 - 34, height() - 4) };
+            QPoint(width() - 10 - 34, baseY - 3),
+            QPoint(width() - 4 - 34, baseY - 3),
+            QPoint(width() - 7 - 34, baseY) };
         p.drawPolygon(points, 3); // TODO: use QStyle
         p.restore();
     }
@@ -334,8 +355,9 @@ bool KSMPushButton::event( QEvent *e )
 Q_DECLARE_METATYPE(Solid::Control::PowerManager::SuspendMethod)
 
 KSMShutdownDlg::KSMShutdownDlg( QWidget* parent,
-                                bool maysd, KWorkSpace::ShutdownType sdtype )
+                                bool maysd, bool choose, KWorkSpace::ShutdownType sdtype )
   : QDialog( parent, Qt::Popup ), //krazy:exclude=qclasses
+    m_lastButton(0),
     m_btnLogout(0),
     m_btnHalt(0),
     m_btnReboot(0),
@@ -365,7 +387,14 @@ KSMShutdownDlg::KSMShutdownDlg( QWidget* parent,
 
     QVBoxLayout *mainLayout = new QVBoxLayout();
 
-    mainLayout->setContentsMargins(12, 9, 12, 7);
+    qreal left, top, right, bottom;
+    m_svg->getMargins(left, top, right, bottom);
+    //not in framesvg mode
+    if (left == 0) {
+        mainLayout->setContentsMargins(12, 9, 12, 7);
+    } else {
+        mainLayout->setContentsMargins(left, top, right, bottom);
+    }
 
     QVBoxLayout *buttonLayout = new QVBoxLayout();
     QHBoxLayout *buttonMainLayout = new QHBoxLayout();
@@ -383,84 +412,78 @@ KSMShutdownDlg::KSMShutdownDlg( QWidget* parent,
     QPalette palette;
     palette.setColor(QPalette::WindowText, fntColor);
 
-    m_btnLogout = new KSMPushButton( i18n("&Logout"), this );
-    m_btnLogout->setPixmap(KIconLoader::global()->loadIcon("system-log-out", KIconLoader::NoGroup, 32));
-    if ( sdtype == KWorkSpace::ShutdownTypeLogout )
-        m_btnLogout->setFocus();
-    connect(m_btnLogout, SIGNAL(clicked()), SLOT(slotLogout()));
-    buttonLayout->addWidget(m_btnLogout, Qt::AlignRight | Qt::AlignTop);
+    if ( choose || sdtype == KWorkSpace::ShutdownTypeNone ) {
+        m_btnLogout = new KSMPushButton( i18n("&Logout"), this );
+        m_btnLogout->setPixmap(KIconLoader::global()->loadIcon("system-log-out", KIconLoader::NoGroup, 32));
+        if ( sdtype == KWorkSpace::ShutdownTypeNone )
+            m_btnLogout->setFocus();
+        connect(m_btnLogout, SIGNAL(clicked()), SLOT(slotLogout()));
+        buttonLayout->addWidget(m_btnLogout, Qt::AlignRight | Qt::AlignTop);
+    }
 
     if (maysd) {
         // Shutdown
-        m_btnHalt = new KSMPushButton( i18n("&Turn Off Computer"), this );
-        m_btnHalt->setPixmap(KIconLoader::global()->loadIcon("system-shutdown", KIconLoader::NoGroup, 32));
-        buttonLayout->addWidget(m_btnHalt, Qt::AlignTop | Qt::AlignRight);
-        connect(m_btnHalt, SIGNAL(clicked()), SLOT(slotHalt()));
-        if ( sdtype == KWorkSpace::ShutdownTypeHalt )
-            m_btnHalt->setFocus();
 
-        QMenu *shutdownMenu = new QMenu( m_btnHalt );
-        QActionGroup* spdActionGroup = new QActionGroup(shutdownMenu);
-        connect( spdActionGroup, SIGNAL(triggered(QAction*)), SLOT(slotSuspend(QAction*)) );
-        m_btnHalt->setPopupMenu( shutdownMenu );
-        Solid::Control::PowerManager::SuspendMethods spdMethods = Solid::Control::PowerManager::supportedSuspendMethods();
-        if( spdMethods & Solid::Control::PowerManager::Standby ) {
-            QAction* action = new QAction(i18n("&Standby"), spdActionGroup);
-            action->setData(QVariant::fromValue(Solid::Control::PowerManager::Standby));
-        }
-        if( spdMethods & Solid::Control::PowerManager::ToRam ) {
-            QAction* action = new QAction(i18n("Suspend to &RAM"), spdActionGroup);
-            action->setData(QVariant::fromValue(Solid::Control::PowerManager::ToRam));
-        }
-        if( spdMethods & Solid::Control::PowerManager::ToDisk ) {
-            QAction* action = new QAction(i18n("Suspend to &Disk"), spdActionGroup);
-            action->setData(QVariant::fromValue(Solid::Control::PowerManager::ToDisk));
-        }
-        shutdownMenu->addActions(spdActionGroup->actions());
+        if ( choose || sdtype == KWorkSpace::ShutdownTypeHalt ) {
+            m_btnHalt = new KSMPushButton( i18n("&Turn Off Computer"), this );
+            m_btnHalt->setPixmap(KIconLoader::global()->loadIcon("system-shutdown", KIconLoader::NoGroup, 32));
+            buttonLayout->addWidget(m_btnHalt, Qt::AlignTop | Qt::AlignRight);
+            connect(m_btnHalt, SIGNAL(clicked()), SLOT(slotHalt()));
+            if ( sdtype == KWorkSpace::ShutdownTypeHalt )
+                m_btnHalt->setFocus();
 
-        // Reboot
-        m_btnReboot = new KSMPushButton( i18n("&Restart Computer"), this );
-        m_btnReboot->setPixmap(KIconLoader::global()->loadIcon("system-restart", KIconLoader::NoGroup, 32));
-        connect(m_btnReboot, SIGNAL(clicked()), SLOT(slotReboot()));
-        buttonLayout->addWidget(m_btnReboot, Qt::AlignTop | Qt::AlignRight);
-        if ( sdtype == KWorkSpace::ShutdownTypeReboot )
-            m_btnReboot->setFocus();
-
-        int def, cur;
-        if ( KDisplayManager().bootOptions( rebootOptions, def, cur ) ) {
-            if ( cur == -1 )
-                cur = def;
-
-            QMenu *rebootMenu = new QMenu( m_btnReboot );
-            QActionGroup* rebootActionGroup = new QActionGroup(rebootMenu);
-            connect( rebootActionGroup, SIGNAL(triggered(QAction*)), SLOT(slotReboot(QAction*)) );
-            m_btnReboot->setPopupMenu( rebootMenu );
-
-            int index = 0;
-            for (QStringList::ConstIterator it = rebootOptions.constBegin(); it != rebootOptions.constEnd(); ++it, ++index) {
-                QString label = (*it);
-                label=label.replace('&',"&&");
-                QAction* action = new QAction(label, rebootActionGroup);
-                action->setData(index);
-                if (index == cur) {
-                    action->setText( label + i18nc("current option in boot loader", " (current)") );
-                }
+            QMenu *shutdownMenu = new QMenu( m_btnHalt );
+            QActionGroup* spdActionGroup = new QActionGroup(shutdownMenu);
+            connect( spdActionGroup, SIGNAL(triggered(QAction*)), SLOT(slotSuspend(QAction*)) );
+            m_btnHalt->setPopupMenu( shutdownMenu );
+            Solid::Control::PowerManager::SuspendMethods spdMethods = Solid::Control::PowerManager::supportedSuspendMethods();
+            if( spdMethods & Solid::Control::PowerManager::Standby ) {
+                QAction* action = new QAction(i18n("&Standby"), spdActionGroup);
+                action->setData(QVariant::fromValue(Solid::Control::PowerManager::Standby));
             }
-            rebootMenu->addActions(rebootActionGroup->actions());
+            if( spdMethods & Solid::Control::PowerManager::ToRam ) {
+                QAction* action = new QAction(i18n("Suspend to &RAM"), spdActionGroup);
+                action->setData(QVariant::fromValue(Solid::Control::PowerManager::ToRam));
+            }
+            if( spdMethods & Solid::Control::PowerManager::ToDisk ) {
+                QAction* action = new QAction(i18n("Suspend to &Disk"), spdActionGroup);
+                action->setData(QVariant::fromValue(Solid::Control::PowerManager::ToDisk));
+            }
+            shutdownMenu->addActions(spdActionGroup->actions());
         }
-    }
 
-    if ( sdtype == KWorkSpace::ShutdownTypeLogout ) {
-        m_btnReboot->setHidden(true);
-        m_btnHalt->setHidden(true);
-    }
-    else if ( sdtype == KWorkSpace::ShutdownTypeHalt ) {
-        m_btnReboot->setHidden(true);
-        m_btnLogout->setHidden(true);
-    }
-    else if ( sdtype == KWorkSpace::ShutdownTypeReboot ) {
-        m_btnHalt->setHidden(true);
-        m_btnLogout->setHidden(true);
+        if ( choose || sdtype == KWorkSpace::ShutdownTypeReboot ) {
+            // Reboot
+            m_btnReboot = new KSMPushButton( i18n("&Restart Computer"), this );
+            m_btnReboot->setPixmap(KIconLoader::global()->loadIcon("system-reboot", KIconLoader::NoGroup, 32));
+            connect(m_btnReboot, SIGNAL(clicked()), SLOT(slotReboot()));
+            buttonLayout->addWidget(m_btnReboot, Qt::AlignTop | Qt::AlignRight);
+            if ( sdtype == KWorkSpace::ShutdownTypeReboot )
+                m_btnReboot->setFocus();
+
+            int def, cur;
+            if ( KDisplayManager().bootOptions( rebootOptions, def, cur ) ) {
+                if ( cur == -1 )
+                    cur = def;
+
+                QMenu *rebootMenu = new QMenu( m_btnReboot );
+                QActionGroup* rebootActionGroup = new QActionGroup(rebootMenu);
+                connect( rebootActionGroup, SIGNAL(triggered(QAction*)), SLOT(slotReboot(QAction*)) );
+                m_btnReboot->setPopupMenu( rebootMenu );
+
+                int index = 0;
+                for (QStringList::ConstIterator it = rebootOptions.constBegin(); it != rebootOptions.constEnd(); ++it, ++index) {
+                    QString label = (*it);
+                    label=label.replace('&',"&&");
+                    QAction* action = new QAction(label, rebootActionGroup);
+                    action->setData(index);
+                    if (index == cur) {
+                        action->setText( label + i18nc("default option in boot loader", " (default)") );
+                    }
+                }
+                rebootMenu->addActions(rebootActionGroup->actions());
+            }
+        }
     }
 
     btnBack = new KSMPushButton(i18n("&Cancel"), this, true);
@@ -516,6 +539,10 @@ KSMShutdownDlg::KSMShutdownDlg( QWidget* parent,
 void KSMShutdownDlg::automaticallyDoTimeout()
 {
     QPushButton *focusedButton = qobject_cast<QPushButton *>(focusWidget());
+    if (focusedButton != m_lastButton) {
+        m_lastButton = focusedButton;
+        m_automaticallyDoSeconds = 30;
+    }
     if (focusedButton) {
         if (m_automaticallyDoSeconds <= 0) { // timeout is at 0, do selected action
                 focusedButton->click();
@@ -560,6 +587,7 @@ void KSMShutdownDlg::paintEvent(QPaintEvent *e)
         QRect r = layout()->geometry();
         r.setWidth(m_pictureWidth);
 
+	m_svg->resize();
         m_svg->resize(m_svg->elementRect("picture").size());
         QPixmap picture = m_svg->pixmap("picture");
         m_svg->resize();
@@ -596,14 +624,10 @@ void KSMShutdownDlg::resizeEvent(QResizeEvent *e)
     if( KWindowSystem::compositingActive()) {
         clearMask();
     } else {
-        QBitmap mask(size());
-        mask.fill(Qt::color0);
-
-        QPainter p(&mask);
-        m_svg->resize(size());
-        m_svg->paint(&p, QRect(0, 0, width(), height()), "background");
-        setMask(mask);
+        setMask(m_svg->mask());
     }
+
+    KDialog::centerOnScreen(this);
 }
 
 void KSMShutdownDlg::slotLogout()
@@ -648,11 +672,12 @@ void KSMShutdownDlg::slotSuspend(QAction* action)
     reject();
 }
 
-bool KSMShutdownDlg::confirmShutdown( bool maysd, KWorkSpace::ShutdownType& sdtype, QString& bootOption )
+bool KSMShutdownDlg::confirmShutdown(
+        bool maysd, bool choose, KWorkSpace::ShutdownType& sdtype, QString& bootOption )
 {
     KSMShutdownDlg* l = new KSMShutdownDlg( 0,
                                             //KSMShutdownFeedback::self(),
-                                            maysd, sdtype );
+                                            maysd, choose, sdtype );
     XClassHint classHint;
     classHint.res_name = const_cast<char*>("ksmserver");
     classHint.res_class = const_cast<char*>("ksmserver");
