@@ -20,7 +20,6 @@
 */
 
 #include <kacceleratormanager.h>
-#include <kcolorbutton.h>
 #include <kcolordialog.h>
 #include <klineedit.h>
 #include <klocale.h>
@@ -29,6 +28,8 @@
 #include <QtCore/QAbstractTableModel>
 #include <QtCore/QList>
 #include <QtGui/QCheckBox>
+#include <QtGui/QDoubleSpinBox>
+#include <QtGui/QFormLayout>
 #include <QtGui/QGridLayout>
 #include <QtGui/QGroupBox>
 #include <QtGui/QHeaderView>
@@ -38,7 +39,8 @@
 #include <QtGui/QPixmap>
 #include <QtGui/QPushButton>
 #include <QtGui/QTreeView>
-#include <QDoubleValidator>
+
+#include <limits>
 
 #include "FancyPlotterSettings.h"
 
@@ -46,11 +48,10 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   : KPageDialog( parent ), mModel( new SensorModel( this ) )
 {
   setFaceType( Tabbed );
-  setCaption( i18n( "Signal Plotter Settings" ) );
+  setCaption( i18n( "Plotter Settings" ) );
   setButtons( Ok | Apply | Cancel );
   setObjectName( "FancyPlotterSettings" );
   setModal( false );
-  showButtonSeparator( false );
 
   QFrame *page = 0;
   QGridLayout *pageLayout = 0;
@@ -86,53 +87,50 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   pageLayout->setSpacing( spacingHint() );
   pageLayout->setMargin( 0 );
 
-  groupBox = new QGroupBox( i18n( "Vertical Scale" ), page );
+  groupBox = new QGroupBox( i18n( "Vertical scale" ), page );
   boxLayout = new QGridLayout;
   groupBox->setLayout( boxLayout );
   boxLayout->setSpacing( spacingHint() );
   boxLayout->setColumnStretch( 2, 1 );
 
-  mUseAutoRange = new QCheckBox( i18n( "Automatic range detection" ), groupBox );
-  mUseAutoRange->setWhatsThis( i18n( "Check this box if you want the display range to adapt dynamically to the currently displayed values; if you do not check this, you have to specify the range you want in the fields below." ) );
-  boxLayout->addWidget( mUseAutoRange, 0, 0, 1, 5 );
+  mManualRange = new QCheckBox( i18n( "Specify graph range:" ), groupBox );
+  mManualRange->setWhatsThis( i18n( "Check this box if you want the display range to adapt dynamically to the currently displayed values; if you do not check this, you have to specify the range you want in the fields below." ) );
+  mManualRange->setChecked(true);
+  boxLayout->addWidget( mManualRange, 0, 0, 1, 5 );
 
-  label = new QLabel( i18n( "Minimum value:" ), groupBox );
-  boxLayout->addWidget( label, 1, 0 );
+  mMinValueLabel = new QLabel( i18n( "Minimum value:" ), groupBox );
+  boxLayout->addWidget( mMinValueLabel, 1, 0 );
 
-  mMinValue = new KLineEdit( groupBox );
-  mMinValue->setValidator(new QDoubleValidator(mMinValue));
-  mMinValue->setAlignment( Qt::AlignRight );
-  mMinValue->setEnabled( false );
-  mMinValue->setWhatsThis( i18n( "Enter the minimum value for the display here. If both values are 0, automatic range detection is enabled." ) );
+  mMinValue = new QDoubleSpinBox( groupBox );
+  mMinValue->setMaximum( std::numeric_limits<long long>::max());
+  mMinValue->setMinimum( std::numeric_limits<long long>::min());
+  mMinValue->setWhatsThis( i18n( "Enter the minimum value for the display here." ) );
+  mMinValue->setSingleStep(10);
   boxLayout->addWidget( mMinValue, 1, 1 );
-  label->setBuddy( mMinValue );
+  mMinValueLabel->setBuddy( mMinValue );
 
-  label = new QLabel( i18n( "Maximum value:" ), groupBox );
-  boxLayout->addWidget( label, 1, 3 );
+  mMaxValueLabel = new QLabel( i18n( "Maximum value:" ), groupBox );
+  boxLayout->addWidget( mMaxValueLabel, 1, 3 );
 
-  mMaxValue = new KLineEdit( groupBox );
-  mMaxValue->setAlignment( Qt::AlignRight );
-  mMaxValue->setValidator(new QDoubleValidator(mMaxValue));
-  mMaxValue->setEnabled( false );
-  mMaxValue->setWhatsThis( i18n( "Enter the maximum value for the display here. If both values are 0, automatic range detection is enabled." ) );
+  mMaxValue = new QDoubleSpinBox( groupBox);
+  mMaxValue->setMaximum( std::numeric_limits<long long>::max());
+  mMaxValue->setMinimum( std::numeric_limits<long long>::min());
+  mMaxValue->setWhatsThis( i18n( "Enter the soft maximum value for the display here. The upper range will not be reduced below this value, but will still go above this number for values above this value." ) );
+  mMaxValue->setSingleStep(10);
   boxLayout->addWidget( mMaxValue, 1, 4 );
-  label->setBuddy( mMaxValue );
+  mMaxValueLabel->setBuddy( mMaxValue );
 
   pageLayout->addWidget( groupBox, 0, 0 );
 
-  groupBox = new QGroupBox( i18n( "Horizontal Scale" ), page );
-  boxLayout = new QGridLayout;
-  groupBox->setLayout( boxLayout );
-  boxLayout->setSpacing( spacingHint() );
-  boxLayout->setRowStretch( 1, 1 );
+  groupBox = new QGroupBox( i18n( "Horizontal scale" ), page );
+  QFormLayout *formLayout = new QFormLayout(groupBox);
 
   mHorizontalScale = new KIntNumInput( 1, groupBox );
   mHorizontalScale->setMinimum( 1 );
   mHorizontalScale->setMaximum( 50 );
-  boxLayout->addWidget( mHorizontalScale, 0, 0 );
 
-  label = new QLabel( i18n( "pixels per time period" ), groupBox );
-  boxLayout->addWidget( label, 0, 1 );
+  formLayout->addRow( i18n("Pixels per time period:"), mHorizontalScale );
+
 
   pageLayout->addWidget( groupBox, 1, 0 );
 
@@ -186,43 +184,13 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   boxLayout->addWidget( label, 1, 0 );
 
   mFontSize = new KIntNumInput( 8, groupBox );
-  mFontSize->setMinimum( 5 );
-  mFontSize->setMaximum( 24 );
+  mFontSize->setMinimum( 1 );
+  mFontSize->setMaximum( 1000 );
   boxLayout->addWidget( mFontSize, 1, 1 );
   label->setBuddy( mFontSize );
-  boxLayout->setRowStretch( 2, 1 );
 
   pageLayout->addWidget( groupBox, 1, 0 );
 
-  groupBox = new QGroupBox( i18n( "Colors" ), page );
-  boxLayout = new QGridLayout;
-  groupBox->setLayout( boxLayout );
-  boxLayout->setSpacing( spacingHint() );
-
-  label = new QLabel( i18n( "Font:" ), groupBox );
-  boxLayout->addWidget( label, 0, 0 );
-  mFontColor = new KColorButton( groupBox );
-  boxLayout->addWidget( mFontColor, 0, 1 );
-  label->setBuddy( mFontColor );
-
-
-  label = new QLabel( i18n( "Grid lines:" ), groupBox );
-  boxLayout->addWidget( label, 1, 0 );
-  mGridLinesColor = new KColorButton( groupBox );
-  boxLayout->addWidget( mGridLinesColor, 1, 1 );
-  label->setBuddy( mGridLinesColor );
-
-  label = new QLabel( i18n( "Background:" ), groupBox );
-  boxLayout->addWidget( label, 2, 0 );
-
-  mBackgroundColor = new KColorButton( groupBox );
-  boxLayout->addWidget( mBackgroundColor, 2, 1 );
-  label->setBuddy( mBackgroundColor );
-
-  boxLayout->setRowStretch( 3, 1 );
-
-  pageLayout->addWidget( groupBox, 1, 1 );
-
   pageLayout->setRowStretch( 2, 1 );
 
   // Sensors page
@@ -235,10 +203,20 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   pageLayout->setRowStretch( 5, 1 );
 
   mView = new QTreeView( page );
-  mView->header()->setStretchLastSection( true );
+  mView->header()->setStretchLastSection( false );
   mView->setRootIsDecorated( false );
   mView->setItemsExpandable( false );
   mView->setModel( mModel );
+  mView->header()->setResizeMode(QHeaderView::ResizeToContents);
+  bool hideFirstColumn = true;
+  for(int i = 0; i < mModel->rowCount(); i++)
+    if(mModel->data(mModel->index(i, 0)) != "localhost") {
+      hideFirstColumn = false;
+      break;
+    }
+  if(hideFirstColumn)
+    mView->hideColumn(0);
+
   pageLayout->addWidget( mView, 0, 0, 6, 1 );
   connect(mView,SIGNAL(doubleClicked(const QModelIndex &)), this, SLOT(editSensor()));
 
@@ -269,10 +247,15 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
 
   }
 
-  connect( mUseAutoRange, SIGNAL( toggled( bool ) ), mMinValue,
-           SLOT( setDisabled( bool ) ) );
-  connect( mUseAutoRange, SIGNAL( toggled( bool ) ), mMaxValue,
-           SLOT( setDisabled( bool ) ) );
+  connect( mManualRange, SIGNAL( toggled( bool ) ), mMinValue,
+           SLOT( setEnabled( bool ) ) );
+  connect( mManualRange, SIGNAL( toggled( bool ) ), mMaxValue,
+           SLOT( setEnabled( bool ) ) );
+  connect( mManualRange, SIGNAL( toggled( bool ) ), mMinValueLabel,
+           SLOT( setEnabled( bool ) ) );
+  connect( mManualRange, SIGNAL( toggled( bool ) ), mMaxValueLabel,
+           SLOT( setEnabled( bool ) ) );
+
   connect( mShowVerticalLines, SIGNAL( toggled( bool ) ), mVerticalLinesDistance,
            SLOT( setEnabled( bool ) ) );
   connect( mShowVerticalLines, SIGNAL( toggled( bool ) ), mVerticalLinesScroll,
@@ -322,36 +305,45 @@ QString FancyPlotterSettings::title() const
   return mTitle->text();
 }
 
-void FancyPlotterSettings::setUseAutoRange( bool value )
+void FancyPlotterSettings::setRangeUnits( const QString & units )
 {
-  mUseAutoRange->setChecked( value );
-  mMinValue->setEnabled( !value );
-  mMaxValue->setEnabled( !value );
+  mMinValue->setSuffix(' ' + units);
+  mMaxValue->setSuffix(' ' + units);
 }
 
-bool FancyPlotterSettings::useAutoRange() const
+void FancyPlotterSettings::setUseManualRange( bool value )
 {
-  return mUseAutoRange->isChecked();
+  mManualRange->setChecked( value );
+}
+
+bool FancyPlotterSettings::useManualRange() const
+{
+  return mManualRange->isChecked();
 }
 
 void FancyPlotterSettings::setMinValue( double min )
 {
-  mMinValue->setText( QString::number( min ) );
+  mMinValue->setValue( min );
 }
 
 double FancyPlotterSettings::minValue() const
 {
-  return mMinValue->text().toDouble();
+  return mMinValue->value();
 }
 
 void FancyPlotterSettings::setMaxValue( double max )
 {
-  mMaxValue->setText( QString::number( max ) );
+  mMaxValue->setValue( max );
 }
 
+void FancyPlotterSettings::setHasIntegerRange( bool hasIntegerRange )
+{
+    mMaxValue->setDecimals( hasIntegerRange?0:2 );
+    mMinValue->setDecimals( hasIntegerRange?0:2 );
+}
 double FancyPlotterSettings::maxValue() const
 {
-  return mMaxValue->text().toDouble();
+  return mMaxValue->value();
 }
 
 void FancyPlotterSettings::setHorizontalScale( int scale )
@@ -376,16 +368,6 @@ bool FancyPlotterSettings::showVerticalLines() const
   return mShowVerticalLines->isChecked();
 }
 
-void FancyPlotterSettings::setGridLinesColor( const QColor &color )
-{
-  mGridLinesColor->setColor( color );
-}
-
-QColor FancyPlotterSettings::gridLinesColor() const
-{
-  return mGridLinesColor->color();
-}
-
 void FancyPlotterSettings::setVerticalLinesDistance( int distance )
 {
   mVerticalLinesDistance->setValue( distance );
@@ -446,25 +428,6 @@ int FancyPlotterSettings::fontSize() const
 {
   return mFontSize->value();
 }
-void FancyPlotterSettings::setFontColor( const QColor &color )
-{
-  mFontColor->setColor( color );
-}
-
-QColor FancyPlotterSettings::fontColor() const
-{
-  return mFontColor->color();
-}
-void FancyPlotterSettings::setBackgroundColor( const QColor &color )
-{
-  mBackgroundColor->setColor( color );
-}
-
-QColor FancyPlotterSettings::backgroundColor() const
-{
-  return mBackgroundColor->color();
-}
-
 void FancyPlotterSettings::setSensors( const SensorModelEntry::List &list )
 {
   mModel->setSensors( list );
@@ -489,12 +452,28 @@ void FancyPlotterSettings::editSensor()
 
   SensorModelEntry sensor = mModel->sensor( index );
 
+  KColorDialog dialog(this, true);
+  connect(&dialog, SIGNAL(colorSelected(const QColor &)), this, SLOT(setColorForSelectedItem(const QColor &)));
   QColor color = sensor.color();
-  int result = KColorDialog::getColor( color, parentWidget() );
-  if ( result == KColorDialog::Accepted ) {
+  dialog.setColor(color);
+  int result = dialog.exec();
+
+  if ( result == KColorDialog::Accepted )
+    sensor.setColor( dialog.color() );
+  //If it's not accepted, make sure we set the color back to how it was
+  mModel->setSensor( sensor, index );
+}
+
+void FancyPlotterSettings::setColorForSelectedItem(const QColor &color)
+{
+    const QModelIndex index = mView->selectionModel()->currentIndex();
+    if ( !index.isValid() )
+        return;
+
+    SensorModelEntry sensor = mModel->sensor( index );
+
     sensor.setColor( color );
     mModel->setSensor( sensor, index );
-  }
 }
 
 void FancyPlotterSettings::removeSensor()
