@@ -1,10 +1,9 @@
 //////////////////////////////////////////////////////////////////////////////
 // oxygentitleanimationdata.h
+// handles transition when window title is changed
 // -------------------
 //
 // Copyright (c) 2009 Hugo Pereira Da Costa <hugo.pereira@free.fr>
-// Copyright (c) 2003, 2004 David Johnson <david@usermode.org>
-// Copyright (c) 2006, 2007 Riccardo Iaconelli <ruphy@fsfe.org>
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -91,8 +90,8 @@ namespace Oxygen
         if( e->timerId() != animationLockTimer_.timerId() )
         { return QObject::timerEvent( e ); }
 
-        // stop veto
-        animationLockTimer_.stop();
+        // unlock
+        unlockAnimations();
 
         if( !isAnimated() )
         {
