@@ -26,6 +26,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kxerrorhandler.h>
 #include <klocale.h>
 #include <kdeversion.h>
+#include <kstandarddirs.h>
+
+#include <qprocess.h>
 
 
 namespace KWin
@@ -33,7 +36,7 @@ namespace KWin
 
 CompositingPrefs::CompositingPrefs()
     : mXgl( false )
-    , mEnableCompositing( false )
+    , mRecommendCompositing( false )
     , mEnableVSync( true )
     , mEnableDirectRendering( true )
     , mStrictBinding( true )
@@ -44,9 +47,9 @@ CompositingPrefs::~CompositingPrefs()
     {
     }
 
-bool CompositingPrefs::enableCompositing() const
+bool CompositingPrefs::recommendCompositing() const
     {
-    return mEnableCompositing;
+    return mRecommendCompositing;
     }
 
 bool CompositingPrefs::compositingPossible()
@@ -107,28 +110,6 @@ QString CompositingPrefs::compositingNotPossibleReason()
 #endif
     }
 
-// This function checks selected compositing setup and returns false if it should not
-// be used even if explicitly configured (unless checks are overridden).
-// More checks like broken XRender setups etc. should be added here.
-bool CompositingPrefs::validateSetup( CompositingType compositingType ) const
-    {
-    switch( compositingType )
-        {
-        case NoCompositing:
-            return false;
-        case OpenGLCompositing:
-            if( mDriver == "software" )
-                {
-                kDebug( 1212 ) << "Software GL renderer detected, forcing compositing off.";
-                return false;
-                }
-            return true; // allow
-        case XRenderCompositing:
-            return true; // xrender - always allow?
-        }
-    abort();
-    }
-
 void CompositingPrefs::detect()
     {
     if( !compositingPossible())
@@ -137,6 +118,20 @@ void CompositingPrefs::detect()
         }
 
 #ifdef KWIN_HAVE_OPENGL_COMPOSITING
+    // HACK: This is needed for AIGLX
+    if( qstrcmp( qgetenv( "KWIN_DIRECT_GL" ), "1" ) != 0 )
+        {
+        // Start an external helper program that initializes GLX and returns
+        // 0 if we can use direct rendering, and 1 otherwise.
+        // The reason we have to use an external program is that after GLX
+        // has been initialized, it's too late to set the LIBGL_ALWAYS_INDIRECT
+        // environment variable.
+        // Direct rendering is preferred, since not all OpenGL extensions are
+        // available with indirect rendering.
+        const QString opengl_test = KStandardDirs::findExe( "kwin_opengl_test" );
+        if ( QProcess::execute( opengl_test ) != 0 )
+            setenv( "LIBGL_ALWAYS_INDIRECT", "1", true );
+        }
     if( !Extensions::glxAvailable())
         {
         kDebug( 1212 ) << "No GLX available";
@@ -235,21 +230,20 @@ void CompositingPrefs::detectDriverAndVersion()
     mGLRenderer = QString((const char*)glGetString( GL_RENDERER ));
     mGLVersion = QString((const char*)glGetString( GL_VERSION ));
     mXgl = detectXgl();
-    kDebug( 1212 ) << "GL vendor is" << mGLVendor;
-    kDebug( 1212 ) << "GL renderer is" << mGLRenderer;
-    kDebug( 1212 ) << "GL version is" << mGLVersion;
-    kDebug( 1212 ) << "XGL:" << ( mXgl ? "yes" : "no" );
 
-    if( mGLRenderer.startsWith( "Mesa DRI Intel" ) || mGLRenderer.startsWith( "Mesa DRI Mobile Intel" ))
+    if( mGLRenderer.startsWith( "Mesa DRI Intel" ) || mGLRenderer.startsWith( "Mesa DRI Mobile Intel" )) // krazy:exclude=strings
         {
         mDriver = "intel";
-        QStringList words = mGLRenderer.split(" ");
-        mVersion = Version( words[ words.count() - 2 ] );
+        QStringList words = mGLRenderer.split(' ');
+        if( QRegExp( "[:digit:]+" ).exactMatch( words[ words.count() - 2 ] ))
+            mVersion = Version( words[ words.count() - 2 ] );
+        else
+            mVersion = Version( words[ words.count() - 3 ] );
         }
     else if( mGLVendor == "NVIDIA Corporation" )
         {
         mDriver = "nvidia";
-        QStringList words = mGLVersion.split(" ");
+        QStringList words = mGLVersion.split(' ');
         mVersion = Version( words[ words.count() - 1 ] );
         }
     else if( mGLVendor == "ATI Technologies Inc." )
@@ -257,7 +251,7 @@ void CompositingPrefs::detectDriverAndVersion()
         mDriver = "fglrx";
         // Ati changed the version string.
         // The GL version is either in the first or second part
-        QStringList versionParts = mGLVersion.split(" ");
+        QStringList versionParts = mGLVersion.split(' ');
         if( versionParts.first().count(".") == 2 || versionParts.count() == 1 )
             mVersion = Version( versionParts.first() );
         else
@@ -266,15 +260,18 @@ void CompositingPrefs::detectDriverAndVersion()
             mVersion = Version( versionParts[1].mid( 1, versionParts[1].length() -2 ) );
             }
         }
-    else if( mGLRenderer.startsWith( "Mesa DRI R" ))
+    else if( mGLRenderer.startsWith( "Mesa DRI R" )) // krazy:exclude=strings
         {
         mDriver = "radeon";
-        mVersion = Version( mGLRenderer.split(" ")[ 3 ] );
+        mVersion = Version( mGLRenderer.split(' ')[ 3 ] );
+        // Check that the version string is changed, and try the fifth element if it does
+        if (!mVersion.startsWith("20"))
+            mVersion = Version( mGLRenderer.split(' ')[ 5 ] );
         }
     else if( mGLRenderer == "Software Rasterizer" )
         {
         mDriver = "software";
-        QStringList words = mGLVersion.split(" ");
+        QStringList words = mGLVersion.split(' ');
         mVersion = Version( words[ words.count() - 1 ] );
         }
     else
@@ -282,63 +279,44 @@ void CompositingPrefs::detectDriverAndVersion()
         mDriver = "unknown";
         }
 
-    kDebug( 1212 ) << "Detected driver" << mDriver << ", version" << mVersion.join(".");
+    // Always output as it's VERY useful
+    kWarning( 1212 ) << "GL vendor is" << mGLVendor;
+    kWarning( 1212 ) << "GL renderer is" << mGLRenderer;
+    kWarning( 1212 ) << "GL version is" << mGLVersion;
+    if( mXgl )
+        kWarning( 1212 ) << "Using XGL";
+    kWarning( 1212 ) << "Detected driver" << mDriver << ", version" << mVersion.join(".");
 #endif
     }
 
 // See http://techbase.kde.org/Projects/KWin/HW for a list of some cards that are known to work.
 void CompositingPrefs::applyDriverSpecificOptions()
     {
+    // Always recommend
+    mRecommendCompositing = true;
+
+    // Known driver specific options
     if( mXgl )
         {
-        kDebug( 1212 ) << "xgl, enabling";
-        mEnableCompositing = true;
         mStrictBinding = false;
         }
     else if( mDriver == "intel" )
         {
-        kDebug( 1212 ) << "intel driver, disabling vsync, enabling direct";
         mEnableVSync = false;
-        mEnableDirectRendering = true;
-        if( mVersion >= Version( "20061017" ))
-            { 
-            if( mGLRenderer.contains( "Intel(R) 9" ))
-                { // Enable compositing by default on 900-series cards
-                kDebug( 1212 ) << "intel >= 20061017 and 900-series card, enabling compositing";
-                mEnableCompositing = true;
-                }
-            if( mGLRenderer.contains( "Mesa DRI Intel(R) G" ))
-                { // e.g. G43 chipset
-                kDebug( 1212 ) << "intel >= 20061017 and Gxx-series card, enabling compositing";
-                mEnableCompositing = true;
-                }
-            }
         }
     else if( mDriver == "nvidia" )
         {
         mStrictBinding = false;
-        if( mVersion >= Version( "173.14.12" ))
-            {
-            kDebug( 1212 ) << "nvidia >= 173.14.12, enabling compositing";
-            mEnableCompositing = true;
-            }
-        }
-    else if( mDriver == "radeon" )
-        { // radeon r200 only ?
-        if( mGLRenderer.startsWith( "Mesa DRI R200" ) && mVersion >= Version( "20060602" ))
-            {
-            kDebug( 1212 ) << "radeon r200 >= 20060602, enabling compositing";
-            mEnableCompositing = true;
-            }
-        }
-    else if( mDriver == "fglrx" )
-        { // radeon r200 only ?
-        if( mVersion >= Version( "2.1.7412" ))
-            {
-            kDebug( 1212 ) << "fglrx >= 2.1.7412, enabling compositing";
-            mEnableCompositing = true;
-            }
         }
+    //else if( mDriver == "fglrx" )
+    //    {
+    //    }
+    //else if( mDriver == "radeon" )
+    //    {
+    //    }
+    //else if( mDriver == "software" )
+    //    {
+    //    }
     }
 
 
