@@ -38,6 +38,10 @@ namespace KWin
 
 KWIN_EFFECT( shadow, ShadowEffect )
 
+enum {
+    ShadowOverrideRole = 0x22A982D1
+};
+
 ShadowEffect::ShadowEffect()
     : shadowSize( 0 )
     {
@@ -45,6 +49,8 @@ ShadowEffect::ShadowEffect()
     reconfigure( ReconfigureAll );
     connect(KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()),
              this, SLOT(updateShadowColor()));
+    shadowOverride = XInternAtom( display(), "_KDE_SHADOW_OVERRIDE", False );
+    effects->registerPropertyType( shadowOverride, true );
     }
 
 ShadowEffect::~ShadowEffect()
@@ -57,6 +63,7 @@ ShadowEffect::~ShadowEffect()
     for( int i = 0; i < mDefaultShadowPics.size(); i++ )
         delete mDefaultShadowPics.at( i );
 #endif
+    effects->registerPropertyType( shadowOverride, false );
     }
 
 void ShadowEffect::reconfigure( ReconfigureFlags )
@@ -155,6 +162,7 @@ void ShadowEffect::updateShadowColor()
 
 QRect ShadowEffect::shadowRectangle( EffectWindow* w, const QRect& windowRectangle ) const
     {
+    Q_UNUSED( w );
     int shadowGrow = shadowFuzzyness + shadowSize;
     return windowRectangle.adjusted( shadowXOffset - shadowGrow, shadowYOffset - shadowGrow,
             shadowXOffset + shadowGrow, shadowYOffset + shadowGrow);
@@ -204,8 +212,9 @@ void ShadowEffect::drawWindow( EffectWindow* w, int mask, QRegion region, Window
             if (optimize)
                 {
                     rgn -= shape;
-                    foreach( ShadowData d, shadowDatas )
-                        d.clip |= shape;
+                    QList<ShadowData>::iterator i;
+                    for( i = shadowDatas.begin(); i != shadowDatas.end(); ++i )
+                        (*i).clip |= shape;
                 }
             optimize = false;
         }
@@ -362,6 +371,21 @@ QRect ShadowEffect::transformWindowDamage( EffectWindow* w, const QRect& r )
     return effects->transformWindowDamage( w, r2 );
     }
 
+void ShadowEffect::propertyNotify( EffectWindow* w, long atom )
+    {
+    if( !w || atom != shadowOverride )
+        return;
+    const QByteArray value = w->readProperty( atom, atom, 32 );
+    w->setData( ShadowOverrideRole, !value.isNull() );
+    effects->addRepaint( shadowRectangle( w, w->geometry() ));
+    }
+
+void ShadowEffect::windowAdded( EffectWindow* c )
+    {
+    const QByteArray value = c->readProperty( shadowOverride, shadowOverride, 32 );
+    c->setData( ShadowOverrideRole, !value.isNull() );
+    }
+
 void ShadowEffect::windowClosed( EffectWindow* c )
     {
     effects->addRepaint( shadowRectangle( c, c->geometry() ));
@@ -372,8 +396,12 @@ bool ShadowEffect::useShadow( EffectWindow* w ) const
     return !w->isDeleted() && !w->isDesktop() && !w->isDock()
         // popups may have shadow even if shaped, their shape is almost rectangular
         && ( !w->hasOwnShape() || w->isDropdownMenu() || w->isPopupMenu() || w->isComboBox())
+        // Ignore windows that draw their own shadows
+        && !w->data( ShadowOverrideRole ).toBool()
         // If decoration has it's own shadow leave it alone
-        && !( w->hasDecoration() && effects->hasDecorationShadows() );
+        && !( w->hasDecoration() && effects->hasDecorationShadows() )
+        && !( w->windowClass() == "ksmserver ksmserver" &&
+                ( w->windowRole() == "logoutdialog" || w->windowRole() == "logouteffect" ));
     }
 
 void ShadowEffect::addQuadVertices(QVector<float>& verts, float x1, float y1, float x2, float y2) const
@@ -422,6 +450,8 @@ void ShadowEffect::drawQueuedShadows( EffectWindow* behindWindow )
 // Modified version of SceneOpenGL::Window::prepareRenderStates() from scene_opengl.cpp
 void ShadowEffect::prepareRenderStates( GLTexture *texture, double opacity, double brightness, double saturation )
     {
+    Q_UNUSED( texture );
+    Q_UNUSED( saturation );
 #ifdef KWIN_HAVE_OPENGL_COMPOSITING
     // setup blending of transparent windows
     glPushAttrib( GL_ENABLE_BIT );
@@ -508,6 +538,7 @@ void ShadowEffect::prepareRenderStates( GLTexture *texture, double opacity, doub
 // Modified version of SceneOpenGL::Window::restoreRenderStates() from scene_opengl.cpp
 void ShadowEffect::restoreRenderStates( GLTexture *texture, double opacity, double brightness, double saturation )
     {
+    Q_UNUSED( texture );
 #ifdef KWIN_HAVE_OPENGL_COMPOSITING
     if( opacity != 1.0 || saturation != 1.0 || brightness != 1.0 )
         {
@@ -558,6 +589,7 @@ void ShadowEffect::drawShadowQuadOpenGL( GLTexture *texture, QVector<float> vert
 void ShadowEffect::drawShadowQuadXRender( XRenderPicture *picture, QRect rect, float xScale, float yScale,
     QColor color, float opacity, float brightness, float saturation )
     {
+    Q_UNUSED( saturation );
 #ifdef KWIN_HAVE_XRENDER_COMPOSITING
     XRenderPicture fill;
     if( color.isValid() )
