@@ -99,7 +99,7 @@ QWidget* KDecoration::initialParentWidget() const
     {
     return bridge_->initialParentWidget();
     }
-    
+
 Qt::WFlags KDecoration::initialWFlags() const
     {
     return bridge_->initialWFlags();
@@ -109,7 +109,7 @@ bool KDecoration::isActive() const
     {
     return bridge_->isActive();
     }
-    
+
 bool KDecoration::isCloseable() const
     {
     return bridge_->isCloseable();
@@ -119,12 +119,12 @@ bool KDecoration::isMaximizable() const
     {
     return bridge_->isMaximizable();
     }
-    
+
 KDecoration::MaximizeMode KDecoration::maximizeMode() const
     {
     return bridge_->maximizeMode();
     }
-    
+
 bool KDecoration::isMinimizable() const
     {
     return bridge_->isMinimizable();
@@ -134,32 +134,32 @@ bool KDecoration::providesContextHelp() const
     {
     return bridge_->providesContextHelp();
     }
-    
+
 int KDecoration::desktop() const
     {
     return bridge_->desktop();
     }
-    
+
 bool KDecoration::isModal() const
     {
     return bridge_->isModal();
     }
-    
+
 bool KDecoration::isShadeable() const
     {
     return bridge_->isShadeable();
     }
-    
+
 bool KDecoration::isShade() const
     {
     return bridge_->isShade();
     }
-    
+
 bool KDecoration::isSetShade() const
     {
     return bridge_->isSetShade();
     }
-    
+
 bool KDecoration::keepAbove() const
     {
     return bridge_->keepAbove();
@@ -189,7 +189,7 @@ QIcon KDecoration::icon() const
     {
     return bridge_->icon();
     }
-    
+
 QString KDecoration::caption() const
     {
     return bridge_->caption();
@@ -204,7 +204,7 @@ void KDecoration::showWindowMenu( const QRect &pos )
     {
     bridge_->showWindowMenu( pos );
     }
-    
+
 void KDecoration::showWindowMenu( QPoint pos )
     {
     bridge_->showWindowMenu( pos );
@@ -219,22 +219,22 @@ void KDecoration::setMask( const QRegion& reg, int mode )
     {
     bridge_->setMask( reg, mode );
     }
-    
+
 void KDecoration::clearMask()
     {
     bridge_->setMask( QRegion(), 0 );
     }
-    
+
 bool KDecoration::isPreview() const
     {
     return bridge_->isPreview();
     }
-    
+
 QRect KDecoration::geometry() const
     {
     return bridge_->geometry();
     }
-    
+
 QRect KDecoration::iconGeometry() const
     {
     return bridge_->iconGeometry();
@@ -249,7 +249,7 @@ WId KDecoration::windowId() const
     {
     return bridge_->windowId();
     }
-        
+
 void KDecoration::closeWindow()
     {
     bridge_->closeWindow();
@@ -264,7 +264,7 @@ void KDecoration::maximize( MaximizeMode mode )
     {
     bridge_->maximize( mode );
     }
-    
+
 void KDecoration::minimize()
     {
     bridge_->minimize();
@@ -274,7 +274,7 @@ void KDecoration::showContextHelp()
     {
     bridge_->showContextHelp();
     }
-    
+
 void KDecoration::setDesktop( int desktop )
     {
     bridge_->setDesktop( desktop );
@@ -302,12 +302,12 @@ void KDecoration::setShade( bool set )
     {
     bridge_->setShade( set );
     }
-        
+
 void KDecoration::setKeepAbove( bool set )
     {
     bridge_->setKeepAbove( set );
     }
-    
+
 void KDecoration::setKeepBelow( bool set )
     {
     bridge_->setKeepBelow( set );
@@ -341,7 +341,7 @@ void KDecoration::grabXServer()
     {
     bridge_->grabXServer( true );
     }
-    
+
 void KDecoration::ungrabXServer()
     {
     bridge_->grabXServer( false );
@@ -382,6 +382,14 @@ KDecoration::Position KDecoration::mousePosition( const QPoint& p ) const
     return m;
     }
 
+QRect KDecoration::transparentRect() const
+    {
+    if (KDecorationBridgeUnstable *bridge2 = dynamic_cast<KDecorationBridgeUnstable*>(bridge_))
+        return bridge2->transparentRect();
+    else
+        return QRect();
+    }
+
 
 KDecorationUnstable::KDecorationUnstable( KDecorationBridge* bridge, KDecorationFactory* factory )
     : KDecoration( bridge, factory )
@@ -403,6 +411,73 @@ void KDecorationUnstable::padding(int &left, int &right, int &top, int &bottom)
     left = right = top = bottom = 0;
     }
 
+// Window tabbing
+
+bool KDecorationUnstable::isClientGroupActive()
+    {
+    return static_cast< KDecorationBridgeUnstable* >( bridge_ )->isClientGroupActive();
+    }
+
+QList< ClientGroupItem > KDecorationUnstable::clientGroupItems() const
+    {
+    return static_cast< KDecorationBridgeUnstable* >( bridge_ )->clientGroupItems();
+    }
+
+long KDecorationUnstable::itemId( int index )
+    {
+    return static_cast< KDecorationBridgeUnstable* >( bridge_ )->itemId( index );
+    }
+
+int KDecorationUnstable::visibleClientGroupItem()
+    {
+    return static_cast< KDecorationBridgeUnstable* >( bridge_ )->visibleClientGroupItem();
+    }
+
+void KDecorationUnstable::setVisibleClientGroupItem( int index )
+    {
+    static_cast< KDecorationBridgeUnstable* >( bridge_ )->setVisibleClientGroupItem( index );
+    }
+
+void KDecorationUnstable::moveItemInClientGroup( int index, int before )
+    {
+    static_cast< KDecorationBridgeUnstable* >( bridge_ )->moveItemInClientGroup( index, before );
+    }
+
+void KDecorationUnstable::moveItemToClientGroup( long itemId, int before )
+    {
+    static_cast< KDecorationBridgeUnstable* >( bridge_ )->moveItemToClientGroup( itemId, before );
+    }
+
+void KDecorationUnstable::removeFromClientGroup( int index, const QRect& newGeom )
+    {
+    static_cast< KDecorationBridgeUnstable* >( bridge_ )->removeFromClientGroup( index, newGeom );
+    }
+
+void KDecorationUnstable::closeClientGroupItem( int index )
+    {
+    static_cast< KDecorationBridgeUnstable* >( bridge_ )->closeClientGroupItem( index );
+    }
+
+void KDecorationUnstable::closeAllInClientGroup()
+    {
+    static_cast< KDecorationBridgeUnstable* >( bridge_ )->closeAllInClientGroup();
+    }
+
+void KDecorationUnstable::displayClientMenu( int index, const QPoint& pos )
+    {
+    static_cast< KDecorationBridgeUnstable* >( bridge_ )->displayClientMenu( index, pos );
+    }
+
+KDecoration::WindowOperation KDecorationUnstable::buttonToWindowOperation( Qt::MouseButtons button )
+    {
+    return static_cast< KDecorationBridgeUnstable* >( bridge_ )->buttonToWindowOperation( button );
+    }
+
+QString KDecorationDefines::clientGroupItemDragMimeType()
+    {
+    return "text/ClientGroupItem";
+    }
+
 KDecorationOptions::KDecorationOptions()
     : d( new KDecorationOptionsPrivate )
     {
@@ -435,14 +510,11 @@ QPalette KDecorationOptions::palette(ColorType type, bool active) const
     int idx = type + (active ? 0 : NUM_COLORS);
     if(d->pal[idx])
         return(*d->pal[idx]);
-#ifdef __GNUC__
-#warning KDE4 : why construct the palette this way?
-#endif    
-                // TODO: Is this worth 'porting' to Qt4?
-//     d->pal[idx] = new QPalette(Qt::black, d->colors[idx], d->colors[idx].light(150),
-//                               d->colors[idx].dark(), d->colors[idx].dark(120),
-//                               Qt::black, QApplication::palette().active().
-//                               base());
+    // TODO: Why construct the palette this way? Is it worth porting to Qt4?
+    //d->pal[idx] = new QPalette(Qt::black, d->colors[idx], d->colors[idx].light(150),
+    //                           d->colors[idx].dark(), d->colors[idx].dark(120),
+    //                           Qt::black, QApplication::palette().active().
+    //                           base());
     d->pal[idx] = new QPalette(d->colors[idx]);
     return(*d->pal[idx]);
     }
@@ -498,7 +570,7 @@ bool KDecorationOptions::moveResizeMaximizedWindows() const
 
 KDecorationDefines::WindowOperation KDecorationOptions::operationMaxButtonClick( Qt::MouseButtons button ) const
     {
-    return button == Qt::RightButton? d->opMaxButtonRightClick : 
+    return button == Qt::RightButton? d->opMaxButtonRightClick :
            button == Qt::MidButton?   d->opMaxButtonMiddleClick :
                                       d->opMaxButtonLeftClick;
     }
