@@ -29,6 +29,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "placement.h"
 #include "utils.h"
+#include "tilinglayoutfactory.h"
 
 namespace KWin
 {
@@ -116,6 +117,21 @@ class Options : public KDecorationOptions
          */
         int shadeHoverInterval;
 
+        /**
+         * Whether tiling is enabled or not
+         */
+        bool tilingOn;
+
+        /**
+         * Tiling Layout
+         */
+        enum TilingLayoutFactory::Layouts tilingLayout;
+
+        /**
+         * Tiling window raise policy.
+         */
+        int tilingRaisePolicy;
+
         /**
            Different Alt-Tab-Styles:
            <ul>
@@ -207,6 +223,11 @@ class Options : public KDecorationOptions
          */
         QStringList ignorePositionClasses;
 
+        /**
+        * support legacy fullscreen windows hack: borderless non-netwm windows with screen geometry
+        */
+        bool legacyFullscreenSupport;
+
         bool checkIgnoreFocusStealing( const Client* c );
 
         WindowOperation operationTitlebarDblClick() { return OpTitlebarDblClick; }
@@ -224,6 +245,7 @@ class Options : public KDecorationOptions
             MouseNextDesktop, MousePreviousDesktop,
             MouseAbove, MouseBelow,
             MouseOpacityMore, MouseOpacityLess,
+            MouseClose, MouseLeftGroupWindow, MouseRightGroupWindow, MouseClientGroupDrag,
             MouseNothing
             };
 
@@ -231,7 +253,7 @@ class Options : public KDecorationOptions
             {
             MouseWheelRaiseLower, MouseWheelShadeUnshade, MouseWheelMaximizeRestore,
             MouseWheelAboveBelow, MouseWheelPreviousNextDesktop,
-            MouseWheelChangeOpacity,
+            MouseWheelChangeOpacity, MouseWheelChangeGroupWindow,
             MouseWheelNothing
             };
 
@@ -288,6 +310,23 @@ class Options : public KDecorationOptions
         * @returns the trigger cooldown for electric borders in milliseconds.
         */
         int electricBorderCooldown();
+        /**
+        * @returns the number of pixels the mouse cursor is pushed back when it
+        * reaches the screen edge.
+        */
+        int electricBorderPushbackPixels() const { return electric_border_pushback_pixels; }
+        /**
+        * @returns true if a window gets maximized when it reaches top screen edge
+        * while being moved.
+        */
+        bool electricBorderMaximize() const { return electric_border_maximize; }
+        /**
+        * @returns true if window is tiled to half screen when reaching left or
+        * right screen edge while been moved
+        */
+        bool electricBorderTiling() const { return electric_border_tiling; }
+
+        bool borderlessMaximizedWindows() const { return borderless_maximized_windows; }
 
         bool topMenuEnabled() const { return topmenus; }
         bool desktopTopMenu() const { return desktop_topmenu; }
@@ -298,27 +337,40 @@ class Options : public KDecorationOptions
         // Whether to hide utility windows for inactive applications.
         bool hideUtilityWindowsForInactive;
 
+        bool inactiveTabsSkipTaskbar;
+        bool autogroupSimilarWindows;
+        bool autogroupInForeground;
+
+        // Desktop effects
+        double animationTimeFactor() const;
+
+        //----------------------
         // Compositing settings
-        bool useCompositing;
+
+        enum GLMode { GLTFP, GLSHM, GLFallback };
+
         CompositingType compositingMode;
+        bool useCompositing; // Separate to mode so the user can toggle
+
+        // General preferences
         HiddenPreviews hiddenPreviews;
         bool unredirectFullscreen;
         bool disableCompositingChecks;
-
-        uint refreshRate;
-        // This is for OpenGL mode
-        int smoothScale; // 0 = no, 1 = yes when transformed,
-                         // 2 = try trilinear when transformed; else 1,
-                         // -1 = auto
-        // This is for XRender mode
+        // OpenGL
+        GLMode glMode;
+        int glSmoothScale;  // 0 = no, 1 = yes when transformed,
+                            // 2 = try trilinear when transformed; else 1,
+                            // -1 = auto
+        bool glVSync;
+        // XRender
         bool xrenderSmoothScale;
 
-        enum GLMode { GLTFP, GLSHM, GLFallback };
-        GLMode glMode;
+        // Settings that should be auto-detected
+        uint refreshRate;
         bool glDirect;
-        bool glVSync;
         bool glStrictBinding;
-        double animationTimeFactor() const;
+
+        //----------------------
 
     private:
         WindowOperation OpTitlebarDblClick;
@@ -352,6 +404,10 @@ class Options : public KDecorationOptions
         int electric_borders;
         int electric_border_delay;
         int electric_border_cooldown;
+        int electric_border_pushback_pixels;
+        bool electric_border_maximize;
+        bool electric_border_tiling;
+        bool borderless_maximized_windows;
         bool show_geometry_tip;
         bool topmenus;
         bool desktop_topmenu;
@@ -360,7 +416,7 @@ class Options : public KDecorationOptions
         int animationSpeed; // 0 - instant, 5 - very slow
 
         MouseCommand wheelToMouseCommand( MouseWheelCommand com, int delta );
-        void reloadCompositingSettings(const CompositingPrefs& prefs);
+        void reloadCompositingSettings();
     };
 
 extern Options* options;
