@@ -82,6 +82,17 @@ void Workspace::storeSession( KConfig* config, SMSavePhase phase )
     KConfigGroup cg(config, "Session");
     int count =  0;
     int active_client = -1;
+
+    if( phase == SMSavePhase2 || phase == SMSavePhase2Full )
+        {
+        cg.writeEntry( "tiling", tilingEnabled() );
+        if( tilingEnabled() )
+            {
+            kDebug(1212) << "Tiling was ON";
+            setTilingEnabled( false );
+            }
+        }
+
     for (ClientList::Iterator it = clients.begin(); it != clients.end(); ++it) 
         {
         Client* c = (*it);
@@ -113,6 +124,7 @@ void Workspace::storeSession( KConfig* config, SMSavePhase phase )
     	    // the config entry is called "iconified" for back. comp. reasons
             // (kconf_update script for updating session files would be too complicated)
             cg.writeEntry( QString("iconified")+n, c->isMinimized() );
+            cg.writeEntry( QString("opacity")+n, c->opacity() );
             // the config entry is called "sticky" for back. comp. reasons
             cg.writeEntry( QString("sticky")+n, c->isOnAllDesktops() );
             cg.writeEntry( QString("shaded")+n, c->isShade() );
@@ -121,11 +133,18 @@ void Workspace::storeSession( KConfig* config, SMSavePhase phase )
             cg.writeEntry( QString("keepBelow")+n, c->keepBelow() );
             cg.writeEntry( QString("skipTaskbar")+n, c->skipTaskbar( true ) );
             cg.writeEntry( QString("skipPager")+n, c->skipPager() );
+            cg.writeEntry( QString("skipSwitcher")+n, c->skipSwitcher() );
             // not really just set by user, but name kept for back. comp. reasons
             cg.writeEntry( QString("userNoBorder")+n, c->noBorder() );
             cg.writeEntry( QString("windowType")+n, windowTypeToTxt( c->windowType()));
             cg.writeEntry( QString("shortcut")+n, c->shortcut().toString());
             cg.writeEntry( QString("stackingOrder")+n, unconstrained_stacking_order.indexOf( c ));
+            int group = 0;
+            if( c->clientGroup() )
+                group = c->clientGroup()->clients().count() > 1 ?
+                    // KConfig doesn't support long so we need to live with less precision on 64-bit systems
+                    static_cast<int>( reinterpret_cast<long>( c->clientGroup() )) : 0;
+            cg.writeEntry( QString("clientGroup")+n, group );
             }
         }
     if( phase == SMSavePhase0 )
@@ -160,6 +179,9 @@ void Workspace::loadSessionInfo()
     {
     session.clear();
     KConfigGroup cg(kapp->sessionConfig(), "Session");
+
+    setTilingEnabled( cg.readEntry( "tiling", false ) );
+
     int count =  cg.readEntry( "count",0 );
     int active_client = cg.readEntry( "active",0 );
     for ( int i = 1; i <= count; i++ ) 
@@ -180,17 +202,21 @@ void Workspace::loadSessionInfo()
         info->fullscreen = cg.readEntry( QString("fullscreen")+n, 0 );
         info->desktop = cg.readEntry( QString("desktop")+n, 0 );
         info->minimized = cg.readEntry( QString("iconified")+n, false );
+        info->opacity = cg.readEntry( QString("opacity")+n, 1.0 );
         info->onAllDesktops = cg.readEntry( QString("sticky")+n, false );
         info->shaded = cg.readEntry( QString("shaded")+n, false );
         info->keepAbove = cg.readEntry( QString("staysOnTop")+n, false  );
         info->keepBelow = cg.readEntry( QString("keepBelow")+n, false  );
         info->skipTaskbar = cg.readEntry( QString("skipTaskbar")+n, false  );
         info->skipPager = cg.readEntry( QString("skipPager")+n, false  );
+        info->skipSwitcher = cg.readEntry( QString("skipSwitcher")+n, false  );
         info->noBorder = cg.readEntry( QString("userNoBorder")+n, false  );
         info->windowType = txtToWindowType( cg.readEntry( QString("windowType")+n, QString() ).toLatin1());
         info->shortcut = cg.readEntry( QString("shortcut")+n, QString() );
         info->active = ( active_client == i );
         info->stackingOrder = cg.readEntry( QString("stackingOrder")+n, -1 );
+        info->clientGroup = cg.readEntry( QString("clientGroup")+n, 0 );
+        info->clientGroupClient = NULL;
         }
     }
 
@@ -264,6 +290,13 @@ SessionInfo* Workspace::takeSessionInfo( Client* c )
                 }
             }
         }
+
+    // Set clientGroupClient for other clients in the same group
+    if( realInfo && realInfo->clientGroup )
+        foreach( SessionInfo* info, session )
+            if( !info->clientGroupClient && info->clientGroup == realInfo->clientGroup )
+                info->clientGroupClient = c;
+
     return realInfo;
     }
 
