@@ -21,10 +21,8 @@
 #ifndef KEPHAL_SCREENS_H
 #define KEPHAL_SCREENS_H
 
-#include <QtCore/QPoint>
-#include <QtCore/QSize>
-#include <QtCore/QObject>
-#include <QtCore/QRect>
+#include <QObject>
+#include <QRect>
 
 #include "kephal_export.h"
 
@@ -35,16 +33,21 @@ namespace Kephal {
 
     /**
      * A Screen is the area that is significant for
-     * displaying windows.
+     * displaying windows. or panels.
      * Every activated Output belongs to exactly one
      * Screen and is completely contained within that
      * Screen. No 2 Screens overlap each other.
+     *
+     * Hence:
+     * 1 Output -> 1 Screen
+     * 2 Non-overlapping Outputs -> 2 Screen
+     * 2 Overlapping Outputs -> 1 Screen
      */
     class KEPHAL_EXPORT Screen : public QObject {
         Q_OBJECT
         public:
             Screen(QObject * parent = 0);
-            
+
             /**
              * Returns the id of this Screen. The id
              * is part of the Configuration and will
@@ -56,11 +59,11 @@ namespace Kephal {
             /**
              * The actual size of the screen in pixels.
              * This is the smallest area possible, so
-             * that all Outputs are completely 
+             * that all Outputs are completely
              * contained.
              */
             virtual QSize size() = 0;
-            
+
             /**
              * The actual position on the framebuffer
              * in pixels.
@@ -75,18 +78,18 @@ namespace Kephal {
              * user forces this.
              */
             virtual bool isPrivacyMode() = 0;
-            
+
             /**
              * Sets the state of the privacy-mode.
              */
             virtual void setPrivacyMode(bool b) = 0;
-            
+
             /**
              * Return a list of Outputs currently
              * being part of this Screen.
              */
             virtual QList<Output *> outputs() = 0;
-            
+
             /**
              * Returns whether this screen is the
              * current primary screen.
@@ -94,15 +97,15 @@ namespace Kephal {
              * since the real value is determined
              * the configuration used.
              */
-            bool isPrimary();
-            
+            bool isPrimary() const;
+
             /**
              * Make this Screen the primary one.
              * This just calls the appropriate
              * method in the Configuration.
              */
             void setAsPrimary();
-            
+
             /**
              * Returns the position and size of the
              * Screen as QRect.
@@ -110,9 +113,9 @@ namespace Kephal {
              */
             QRect geom();
     };
-    
-    
-    
+
+
+
     /**
      * Screens is the entrance-point for all Screen-
      * related operations.
@@ -126,10 +129,10 @@ namespace Kephal {
              * Returns the currently active instance.
              */
             static Screens * self();
-            
+
             Screens(QObject * parent);
             virtual ~Screens();
-            
+
             /**
              * Returns the list of all current
              * Screens.
@@ -137,17 +140,17 @@ namespace Kephal {
              * and a non-zero size.
              */
             virtual QList<Screen *> screens() = 0;
-            
+
             /**
              * Find a Screen by its id.
              */
             virtual Screen * screen(int id);
-            
+
             /**
              * Returns the current primary Screen.
              */
             Screen * primaryScreen();
-            
+
         Q_SIGNALS:
             /**
              * This signal is emitted when a new
@@ -155,6 +158,7 @@ namespace Kephal {
              * being activated or the Configuration
              * being changed.
              */
+            // QDW::screenCountChanged
             void screenAdded(Kephal::Screen * s);
 
             /**
@@ -163,51 +167,62 @@ namespace Kephal {
              * being deactivated or the
              * Configuration being changed.
              */
+            // QDW::screenCountChanged
             void screenRemoved(int id);
-            
+
             /**
              * This signal is emitted when the size
              * of the Screen changes.
              */
+            // QDW::resized
+            // TODO: move to Screen and replace with no args version
             void screenResized(Kephal::Screen * s, QSize oldSize, QSize newSize);
 
             /**
              * This signal is emitted when the
              * position of the Screen changes.
              */
+            // QDW::resized emitted when position changes too - but not documented.
+            // TODO: move to Screen and replace with no args version
             void screenMoved(Kephal::Screen * s, QPoint oldPosition, QPoint newPosition);
-            
+
         protected:
-            static Screens * m_instance;
+            static Screens * s_instance;
     };
-    
+
     /**
      * Defines a handful help methods for common tasks
      */
     class KEPHAL_EXPORT ScreenUtils {
         public:
             /** Returns the number of screens. */
+            // PASSTHRU to QDW
             static int numScreens();
-            
+
             /** Returns the geometry of the given screen */
+            // PASSTHRU to QDW
             static QRect screenGeometry(int id);
-            
+
             /** Returns the size of the given screen */
+            // SYNTACTIC SUGAR around QDW
             static QSize screenSize(int id);
-            
+
             /** Returns the geometry of the whole desktop */
+            // SYNTACTIC SUGAR around QApplication::desktop()->geometry()
             static QRect desktopGeometry();
-            
+
             /** Returns the id of the screen that contains the given point */
+            // SYNTACTIC SUGAR around QDW::screenNumber()
             static int screenId(QPoint p);
-            
+
             /** Returns the id of the primary screen */
+            // SYNTACTIC SUGAR around QDW::primaryScreen
             static int primaryScreenId();
-            
+
         private:
             static int distance(const QRect & r, const QPoint & p);
     };
-    
+
 }
 
 
