@@ -1,19 +1,24 @@
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
+/*****************************************************************
+
+Copyright 2008 Christian Mollekopf <chrigi_1@hotmail.com>
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
  ***************************************************************************/
 
 #ifndef TASKGROUP_H
@@ -40,12 +45,18 @@ public:
     ~TaskGroup();
 
     ItemList members() const;
+    WindowList winIds() const;
+    WindowList directMemberwinIds() const;
+
+    AbstractGroupableItem *getMemberByWId(WId id);
+    //including subgroups
+    int totalSize();
 
     QIcon icon() const;
     void setIcon(const QIcon &icon);
 
     QColor color() const;
-    void setColor(const QColor &color); 
+    void setColor(const QColor &color);
 
     QString name() const;
     void setName(const QString &newName);
@@ -117,9 +128,6 @@ public Q_SLOTS:
     /** remove item from group */
     void remove(AbstractGroupableItem *);
 
-    /** Removes all tasks and groups from this group */
-    void clear();
-
 Q_SIGNALS:
     /** inform visualization about wat is added and removed */
     void itemAdded(AbstractGroupableItem *item);
