@@ -54,7 +54,6 @@ Clock::Clock(QObject *parent, const QVariantList &args)
       m_showSeconds(false),
       m_showTimezone(false),
       m_dateTimezoneBesides(false),
-      m_dateString(0),
       m_layout(0)
 {
     KGlobal::locale()->insertCatalog("libplasmaclock");
@@ -71,36 +70,8 @@ Clock::~Clock()
 void Clock::init()
 {
     ClockApplet::init();
-
-    KConfigGroup cg = config();
-
-    m_showTimezone = cg.readEntry("showTimezone", !isLocalTimezone());
-
-    kDebug() << "showTimezone:" << m_showTimezone;
-
-    m_showDate = cg.readEntry("showDate", false);
-    m_showYear = cg.readEntry("showYear", false);
-    m_showDay = cg.readEntry("showDay", true);
-
-    m_showSeconds = cg.readEntry("showSeconds", false);
-    if (m_showSeconds) {
-        //We don't need to cache the applet if it update every seconds
-        setCacheMode(QGraphicsItem::NoCache);
-    } else {
-        setCacheMode(QGraphicsItem::DeviceCoordinateCache);
-    }
-
-    m_plainClockFont = cg.readEntry("plainClockFont", m_plainClockFont);
-    m_useCustomColor = cg.readEntry("useCustomColor", false);
-    if (m_useCustomColor) {
-        m_plainClockColor = cg.readEntry("plainClockColor", m_plainClockColor);
-    } else {
-        m_plainClockColor = KColorScheme(QPalette::Active, KColorScheme::View, Plasma::Theme::defaultTheme()->colorScheme()).foreground().color();
-    }
-
-    const QFontMetricsF metrics(KGlobalSettings::smallestReadableFont());
-    const QString timeString = KGlobal::locale()->formatTime(QTime(23, 59), m_showSeconds);
-    setMinimumSize(metrics.size(Qt::TextSingleLine, timeString));
+    
+    configChanged();
 
     dataEngine("time")->connectSource(currentTimezone(), this, updateInterval(), intervalAlignment());
     connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(updateColors()));
@@ -186,15 +157,14 @@ void Clock::updateSize()
 void Clock::clockConfigChanged()
 {
     KConfigGroup cg = config();
-    
     m_showTimezone = cg.readEntry("showTimezone", !isLocalTimezone());
-    
+
     kDebug() << "showTimezone:" << m_showTimezone;
-    
+
     m_showDate = cg.readEntry("showDate", false);
     m_showYear = cg.readEntry("showYear", false);
     m_showDay = cg.readEntry("showDay", true);
-    
+
     m_showSeconds = cg.readEntry("showSeconds", false);
     if (m_showSeconds) {
         //We don't need to cache the applet if it update every seconds
@@ -202,15 +172,15 @@ void Clock::clockConfigChanged()
     } else {
         setCacheMode(QGraphicsItem::DeviceCoordinateCache);
     }
-    
+
     m_plainClockFont = cg.readEntry("plainClockFont", m_plainClockFont);
     m_useCustomColor = cg.readEntry("useCustomColor", false);
     if (m_useCustomColor) {
         m_plainClockColor = cg.readEntry("plainClockColor", m_plainClockColor);
     } else {
-        m_plainClockColor = KColorScheme(QPalette::Active, KColorScheme::View, Plasma::Theme::defaultTheme()->colorScheme()).foreground().color();
+        updateColors();
     }
-    
+
     const QFontMetricsF metrics(KGlobalSettings::smallestReadableFont());
     const QString timeString = KGlobal::locale()->formatTime(QTime(23, 59), m_showSeconds);
     setMinimumSize(metrics.size(Qt::TextSingleLine, timeString));
@@ -235,6 +205,7 @@ void Clock::dataUpdated(const QString &source, const Plasma::DataEngine::Data &d
         if (Plasma::ToolTipManager::self()->isVisible(this)) {
             updateTipContent();
         }
+        updateClockApplet();
 
         update();
         speakTime(m_time);
@@ -297,7 +268,7 @@ void Clock::clockConfigAccepted()
     if (m_useCustomColor) {
         m_plainClockColor = ui.plainClockColor->color();
     } else {
-        m_plainClockColor = KColorScheme(QPalette::Active, KColorScheme::View, Plasma::Theme::defaultTheme()->colorScheme()).foreground().color();
+        updateColors();
     }
 
     m_plainClockFont.setBold(ui.plainClockFontBold->checkState() == Qt::Checked);
@@ -343,7 +314,7 @@ QRectF Clock::normalLayout(int subtitleWidth, int subtitleHeight, const QRect &c
 QRectF Clock::sideBySideLayout(int subtitleWidth, int subtitleHeight, const QRect &contentsRect)
 {
     QRectF myRect = QRectF(contentsRect.right()-subtitleWidth,
-                           (contentsRect.bottom()-subtitleHeight)/2,
+                           contentsRect.top() + (contentsRect.height()-subtitleHeight)/2,
                            subtitleWidth,
                            subtitleHeight);
     // kDebug(96669) << "myRect: " << myRect;
@@ -582,7 +553,7 @@ Plasma::IntervalAlignment Clock::intervalAlignment() const
 void Clock::updateColors()
 {
     if (!m_useCustomColor) {
-        m_plainClockColor = KColorScheme(QPalette::Active, KColorScheme::View, Plasma::Theme::defaultTheme()->colorScheme()).foreground().color();
+        m_plainClockColor = Plasma::Theme::defaultTheme()->color(Plasma::Theme::TextColor);
         update();
     }
 }
