@@ -25,38 +25,42 @@
 #include <QGraphicsSceneResizeEvent>
 #include <QLabel>
 #include <QPainter>
+#include <QParallelAnimationGroup>
 #include <QTimer>
 
 
 #include <KIconLoader>
 
-#include <Plasma/Animator>
-#include <Plasma/IconWidget>
-#include <Plasma/Label>
-#include <Plasma/Separator>
-#include <Plasma/Svg>
-#include <Plasma/Theme>
-
+#include <plasma/animations/animation.h>
+#include <plasma/applet.h>
+#include <plasma/svg.h>
+#include <plasma/theme.h>
 
 AppletTitleBar::AppletTitleBar(Plasma::Applet *applet)
        : QGraphicsWidget(applet),
          m_applet(applet),
          m_pressedButton(NoButton),
-         m_maximizeButtonAnimationId(0),
-         m_configureButtonAnimationId(0),
-         m_closeButtonAnimationId(0),
          m_separator(0),
          m_background(0),
          m_savedAppletTopMargin(0),
          m_underMouse(false),
-         m_showButtons(false)
+         m_showButtons(false),
+         m_appletHasBackground(false)
 {
+    setObjectName("TitleBar");
+    m_pulse =
+    Plasma::Animator::create(Plasma::Animator::PulseAnimation);
+    m_pulse->setTargetWidget(applet);
+
     m_maximizeButtonRect = m_configureButtonRect = m_closeButtonRect = QRect(0, 0, KIconLoader::SizeSmallMedium, KIconLoader::SizeSmallMedium);
 
     m_icons = new Plasma::Svg(this);
     m_icons->setImagePath("widgets/configuration-icons");
     m_icons->setContainsMultipleImages(true);
 
+    if (applet->backgroundHints() != Plasma::Applet::NoBackground) {
+        m_appletHasBackground = true;
+    }
 
     if (applet->backgroundHints() & Plasma::Applet::StandardBackground ||
         applet->backgroundHints() & Plasma::Applet::TranslucentBackground) {
@@ -76,15 +80,45 @@ AppletTitleBar::AppletTitleBar(Plasma::Applet *applet)
         connect(applet->containment(), SIGNAL(appletRemoved(Plasma::Applet *)), this, SLOT(appletRemoved(Plasma::Applet *)));
     }
     connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(themeChanged()));
-
-    connect(Plasma::Animator::self(), SIGNAL(elementAnimationFinished(int)), this, SLOT(animationFinished(int)));
 }
 
 AppletTitleBar::~AppletTitleBar()
 {
+    delete m_pulse;
+    delete m_animations.data();
 }
 
 
+void AppletTitleBar::initAnimations()
+{
+    if (m_animations) {
+        return;
+    }
+
+    m_animations = new QParallelAnimationGroup(this);
+    QParallelAnimationGroup *group = m_animations.data();
+
+    if (m_applet->hasValidAssociatedApplication()) {
+        Plasma::Animation *maximizeAnim =
+        Plasma::Animator::create(Plasma::Animator::PixmapTransitionAnimation);
+        maximizeAnim->setProperty("targetPixmap", m_icons->pixmap("maximize"));
+        maximizeAnim->setTargetWidget(this);
+        group->addAnimation(maximizeAnim);
+    }
+
+    Plasma::Animation *confAnim =
+        Plasma::Animator::create(Plasma::Animator::PixmapTransitionAnimation);
+    Plasma::Animation *closeAnim =
+        Plasma::Animator::create(Plasma::Animator::PixmapTransitionAnimation);
+    confAnim->setProperty("targetPixmap", m_icons->pixmap("configure"));
+    confAnim->setTargetWidget(this);
+
+    closeAnim->setProperty("targetPixmap", m_icons->pixmap("close"));
+    closeAnim->setTargetWidget(this);
+    group->addAnimation(confAnim);
+    group->addAnimation(closeAnim);
+}
+
 void AppletTitleBar::syncMargins()
 {
     const int extraMargin = 2;
@@ -154,53 +188,35 @@ void AppletTitleBar::syncIconRects()
 bool AppletTitleBar::eventFilter(QObject *watched, QEvent *event)
 {
     Q_UNUSED(watched)
+
     if (event->type() == QEvent::GraphicsSceneResize) {
         syncSize();
     } else if (event->type() == QEvent::GraphicsSceneHoverEnter) {
         m_underMouse = true;
-        m_showButtons = true;
         syncIconRects();
 
-        if (m_maximizeButtonAnimationId) {
-            Plasma::Animator::self()->stopElementAnimation(m_maximizeButtonAnimationId);
-        }
-        m_maximizeButtonAnimationId = Plasma::Animator::self()->animateElement(this, Plasma::Animator::AppearAnimation);
-        Plasma::Animator::self()->setInitialPixmap(m_maximizeButtonAnimationId, m_icons->pixmap("maximize"));
+        if (!m_animations) {
+            initAnimations();
 
-        if (m_configureButtonAnimationId) {
-            Plasma::Animator::self()->stopElementAnimation(m_maximizeButtonAnimationId);
-        }
-        m_configureButtonAnimationId = Plasma::Animator::self()->animateElement(this, Plasma::Animator::AppearAnimation);
-        Plasma::Animator::self()->setInitialPixmap(m_configureButtonAnimationId, m_icons->pixmap("configure"));
+            m_animations.data()->start();
+            m_animations.data()->setCurrentTime(0);
+            connect(m_animations.data(), SIGNAL(finished()), this, SLOT(animationFinished()));
+        } else {
+            QParallelAnimationGroup *group = m_animations.data();
 
-        if (m_closeButtonAnimationId) {
-            Plasma::Animator::self()->stopElementAnimation(m_maximizeButtonAnimationId);
-        }
-        m_closeButtonAnimationId = Plasma::Animator::self()->animateElement(this, Plasma::Animator::AppearAnimation);
-        Plasma::Animator::self()->setInitialPixmap(m_closeButtonAnimationId, m_icons->pixmap("close"));
+            group->stop();
+            group->setCurrentTime(0);
 
-        update();
+            group->start();
+        }
+
+        m_showButtons = true;
     } else if (event->type() == QEvent::GraphicsSceneHoverLeave) {
         m_underMouse = false;
-        if (m_maximizeButtonAnimationId) {
-            Plasma::Animator::self()->stopElementAnimation(m_maximizeButtonAnimationId);
-        }
-        m_maximizeButtonAnimationId = Plasma::Animator::self()->animateElement(this, Plasma::Animator::DisappearAnimation);
-        Plasma::Animator::self()->setInitialPixmap(m_maximizeButtonAnimationId, m_icons->pixmap("maximize"));
-
-        if (m_configureButtonAnimationId) {
-            Plasma::Animator::self()->stopElementAnimation(m_maximizeButtonAnimationId);
-        }
-        m_configureButtonAnimationId = Plasma::Animator::self()->animateElement(this, Plasma::Animator::DisappearAnimation);
-        Plasma::Animator::self()->setInitialPixmap(m_configureButtonAnimationId, m_icons->pixmap("configure"));
-
-        if (m_closeButtonAnimationId) {
-            Plasma::Animator::self()->stopElementAnimation(m_maximizeButtonAnimationId);
-        }
-        m_closeButtonAnimationId = Plasma::Animator::self()->animateElement(this, Plasma::Animator::DisappearAnimation);
-        Plasma::Animator::self()->setInitialPixmap(m_closeButtonAnimationId, m_icons->pixmap("close"));
-
-        update();
+        initAnimations();
+        QParallelAnimationGroup *group = m_animations.data();
+        group->setDirection(QAbstractAnimation::Backward);
+        group->start(QAbstractAnimation::DeleteWhenStopped);
     }
 
     return false;
@@ -213,14 +229,17 @@ void AppletTitleBar::mousePressEvent(QGraphicsSceneMouseEvent *event)
         m_pressedButton = MaximizeButton;
         m_maximizeButtonRect.translate(1, 1);
         update(m_maximizeButtonRect);
+        event->accept();
     } else if (m_configureButtonRect.contains(event->pos())) {
         m_configureButtonRect.translate(1, 1);
         m_pressedButton = ConfigureButton;
         update(m_configureButtonRect);
+        event->accept();
     } else if (m_closeButtonRect.contains(event->pos())) {
         m_closeButtonRect.translate(1, 1);
         m_pressedButton = CloseButton;
         update(m_closeButtonRect);
+        event->accept();
     } else {
         event->ignore();
     }
@@ -235,6 +254,7 @@ void AppletTitleBar::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
     if (m_pressedButton == MaximizeButton && m_maximizeButtonRect.contains(event->pos())) {
         if (m_applet->hasValidAssociatedApplication()) {
+            m_pulse->start();
             m_applet->runAssociatedApplication();
         }
     } else if (m_pressedButton == ConfigureButton && m_configureButtonRect.contains(event->pos())) {
@@ -242,7 +262,7 @@ void AppletTitleBar::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
             m_applet->showConfigurationInterface();
         }
     } else if (m_pressedButton == CloseButton && m_closeButtonRect.contains(event->pos())) {
-        if (m_applet->containment()->immutability() == Plasma::Mutable) {
+        if (m_applet->immutability() == Plasma::Mutable) {
             m_applet->destroy();
         }
     } else {
@@ -283,33 +303,53 @@ void AppletTitleBar::paint(QPainter *painter, const QStyleOptionGraphicsItem *op
     Q_UNUSED(option)
     Q_UNUSED(widget)
 
-    if (m_background) {
+    if (m_background && (!m_appletHasBackground || m_showButtons)) {
         m_background->paintFrame(painter);
     }
 
     if (m_showButtons) {
+        QParallelAnimationGroup *group = m_animations.data();
+
+        int i = 0;
+
         if (m_applet->hasValidAssociatedApplication()) {
-            if (m_maximizeButtonAnimationId) {
-                QPixmap animPixmap = Plasma::Animator::self()->currentPixmap(m_maximizeButtonAnimationId);
-                painter->drawPixmap(m_maximizeButtonRect, animPixmap, animPixmap.rect());
-            } else {
-                m_icons->paint(painter, m_maximizeButtonRect, "maximize");
+            if (group) {
+                if (group->state() == QAbstractAnimation::Running) {
+                    QAbstractAnimation *maximizeAnim = group->animationAt(i);
+                    ++i;
+                    QPixmap animPixmap = qvariant_cast<QPixmap>(maximizeAnim->property("currentPixmap"));
+                    painter->drawPixmap(m_maximizeButtonRect, animPixmap, animPixmap.rect());
+                 } else if (group->state() == QAbstractAnimation::Stopped && group->direction() != QAbstractAnimation::Backward) {
+                     m_icons->paint(painter, m_maximizeButtonRect, "maximize");
+                 }
             }
         }
+
         if (m_applet->hasConfigurationInterface()) {
-            if (m_maximizeButtonAnimationId) {
-                QPixmap animPixmap = Plasma::Animator::self()->currentPixmap(m_configureButtonAnimationId);
-                painter->drawPixmap(m_configureButtonRect, animPixmap, animPixmap.rect());
-            } else {
-                m_icons->paint(painter, m_configureButtonRect, "configure");
+            if (group) {
+                if (group->state() == QAbstractAnimation::Running) {
+                    QAbstractAnimation *confAnim = group->animationAt(i);
+                    ++i;
+                    QPixmap animPixmap = qvariant_cast<QPixmap>(confAnim->property("currentPixmap"));
+                    painter->drawPixmap(m_configureButtonRect, animPixmap, animPixmap.rect());
+                 } else if (group->state() == QAbstractAnimation::Stopped && group->direction() != QAbstractAnimation::Backward) {
+                     m_icons->paint(painter, m_configureButtonRect, "configure");
+                 }
             }
         }
-        if (m_applet->containment()->immutability() == Plasma::Mutable) {
-            if (m_maximizeButtonAnimationId) {
-                QPixmap animPixmap = Plasma::Animator::self()->currentPixmap(m_closeButtonAnimationId);
-                painter->drawPixmap(m_closeButtonRect, animPixmap, animPixmap.rect());
-            } else {
-                m_icons->paint(painter, m_closeButtonRect, "close");
+
+        if (m_applet->immutability() == Plasma::Mutable) {
+            if (group) {
+                if (group->state() == QAbstractAnimation::Running) {
+                    QAbstractAnimation *closeAnim = group->animationAt(i);
+                    if (closeAnim) {
+                        ++i;
+                        QPixmap animPixmap = qvariant_cast<QPixmap>(closeAnim->property("currentPixmap"));
+                        painter->drawPixmap(m_closeButtonRect, animPixmap, animPixmap.rect());
+                    }
+                } else if (group->state() == QAbstractAnimation::Stopped && group->direction() != QAbstractAnimation::Backward) {
+                   m_icons->paint(painter, m_closeButtonRect, "close");
+                }
             }
         }
     }
@@ -344,19 +384,12 @@ void AppletTitleBar::themeChanged()
     QTimer::singleShot(0, this, SLOT(syncMargins()));
 }
 
-void AppletTitleBar::animationFinished(int id)
+void AppletTitleBar::animationFinished()
 {
     if (!m_underMouse) {
         m_showButtons = false;
     }
 
-    if (id == m_maximizeButtonAnimationId) {
-        m_maximizeButtonAnimationId = 0;
-    } else if (id == m_configureButtonAnimationId) {
-        m_configureButtonAnimationId = 0;
-    } else if (id == m_closeButtonAnimationId) {
-        m_closeButtonAnimationId = 0;
-    }
 }
 
 #include <applettitlebar.moc>
