@@ -32,8 +32,9 @@
 #include <solid/button.h>
 #include <solid/genericinterface.h>
 
-HalPower::HalPower(QObject *parent, const QStringList  & /*args */)
+HalPower::HalPower(QObject *parent, const QVariantList  & /*args */)
     : PowerManager(parent),
+      m_brightnessInHardware(true),
       m_halComputer("org.freedesktop.Hal",
                      "/org/freedesktop/Hal/devices/computer",
                      "org.freedesktop.Hal.Device",
@@ -63,6 +64,23 @@ HalPower::HalPower(QObject *parent, const QStringList  & /*args */)
     updateBatteryStats();
 
     computeButtons();
+
+    Solid::Control::PowerManager::BrightnessControlsList controls = brightnessControlsAvailable();
+    QList<QString> screenControls = controls.keys(Solid::Control::PowerManager::Screen);
+
+    if (!screenControls.isEmpty()) {
+        m_cachedBrightness = brightness(screenControls.at(0));
+
+        QDBusInterface deviceInterface("org.freedesktop.Hal",
+                                       screenControls.at(0),
+                                       "org.freedesktop.Hal.Device",
+                                       QDBusConnection::systemBus());
+        QDBusReply<bool> replyInHardware = deviceInterface.call("GetPropertyBoolean",
+                                                                "laptop_panel.brightness_in_hardware");
+        if (replyInHardware.isValid()) {
+            m_brightnessInHardware = replyInHardware;
+        }
+    }
 }
 
 HalPower::~HalPower()
@@ -72,52 +90,8 @@ HalPower::~HalPower()
     qDeleteAll(m_buttons);
 }
 
-QStringList HalPower::supportedSchemes() const
+bool HalPower::setPowerSave(bool powersave)
 {
-    return QStringList() << "performance" << "powersaving";
-}
-
-QString HalPower::schemeDescription(const QString &schemeName) const
-{
-    if (schemeName=="performance")
-    {
-        return "Use all the performances of the system";
-    }
-    else if (schemeName=="powersaving")
-    {
-        return "Try to keep as much power as possible to improve battery life";
-    }
-    else
-    {
-        return QString();
-    }
-
-    return QString();
-}
-
-QString HalPower::scheme() const
-{
-    // FIXME: We miss an accessor in HAL to make scheme management useful
-    return QString();
-}
-
-bool HalPower::setScheme(const QString &name)
-{
-    bool powersave;
-
-    if (name=="powersaving")
-    {
-        powersave = true;
-    }
-    else if (name=="performance")
-    {
-        powersave = false;
-    }
-    else
-    {
-        return false;
-    }
-
     QDBusReply<int> reply = m_halPowerManagement.call("SetPowerSave", powersave);
 
     if (reply.isValid())
@@ -426,7 +400,7 @@ float HalPower::brightness(const QString &device)
     return 0.0;
 }
 
-bool HalPower::setBrightness(float brightness, const QString &device)
+bool HalPower::setBrightness(float brightnessValue, const QString &device)
 {
     QDBusReply<QStringList> reply = m_halManager.call("FindDeviceByCapability", "laptop_panel");
     if(reply.isValid() && reply.value().contains(device))
@@ -434,10 +408,14 @@ bool HalPower::setBrightness(float brightness, const QString &device)
         QDBusInterface propertyInterface("org.freedesktop.Hal", device, "org.freedesktop.Hal.Device", QDBusConnection::systemBus());
         int levels = propertyInterface.call("GetProperty", "laptop_panel.num_levels").arguments().at(0).toInt();
         QDBusInterface deviceInterface("org.freedesktop.Hal", device, "org.freedesktop.Hal.Device.LaptopPanel", QDBusConnection::systemBus());
-        deviceInterface.call("SetBrightness", qRound((levels-1)*(brightness/100.0))); // .0? The right way? Feels hackish.
+        deviceInterface.call("SetBrightness", qRound((levels-1)*(brightnessValue/100.0))); // .0? The right way? Feels hackish.
         if(!deviceInterface.lastError().isValid())
         {
-            emit(brightnessChanged(brightness));
+            float newBrightness = brightness(device);
+            if (!qFuzzyCompare(newBrightness, m_cachedBrightness)) {
+                m_cachedBrightness = newBrightness;
+                emit(brightnessChanged(m_cachedBrightness));
+            }
             return true;
         }
     }
@@ -448,16 +426,41 @@ bool HalPower::setBrightness(float brightness, const QString &device)
         QDBusInterface propertyInterface("org.freedesktop.Hal", device, "org.freedesktop.Hal.Device", QDBusConnection::systemBus());
         int levels = propertyInterface.call("GetProperty", "keyboard_backlight.num_levels").arguments().at(0).toInt();
         QDBusInterface deviceInterface("org.freedesktop.Hal", device, "org.freedesktop.Hal.Device.KeyboardBacklight", QDBusConnection::systemBus()); //TODO - I do not have a backlight enabled keyboard, so I'm guessing a bit here. Could someone please check this.
-        deviceInterface.call("SetBrightness", qRound((levels-1)*(brightness/100.0)));
-        if(!deviceInterface.lastError().isValid())
-        {
-            emit(brightnessChanged(brightness));
+        deviceInterface.call("SetBrightness", qRound((levels-1)*(brightnessValue/100.0)));
+        if(!deviceInterface.lastError().isValid()) {
             return true;
         }
     }
     return false;
 }
 
+void HalPower::brightnessKeyPressed(Solid::Control::PowerManager::BrightnessKeyType type) {
+    Solid::Control::PowerManager::BrightnessControlsList controls = brightnessControlsAvailable();
+    QList<QString> screenControls = controls.keys(Solid::Control::PowerManager::Screen);
+
+    if (screenControls.isEmpty()) {
+        return; // ignore as we are not able to determine the brightness level
+    }
+
+    float currentBrightness = brightness(screenControls.at(0));
+
+    if (qFuzzyCompare(currentBrightness, m_cachedBrightness) && !m_brightnessInHardware)
+    {
+        float newBrightness;
+        if (type == Solid::Control::PowerManager::Increase) {
+            newBrightness = qMin(100.0f, currentBrightness + 10);
+        }
+        else {
+            newBrightness = qMax(0.0f, currentBrightness - 10);
+        }
+
+        setBrightness(newBrightness, screenControls.at(0));
+    }
+    else {
+        m_cachedBrightness = currentBrightness;
+    }
+}
+
 void HalPower::computeAcAdapters()
 {
     QList<Solid::Device> adapters
